@@ -3,7 +3,8 @@
 .conflicts.OK <- TRUE
 
 
-.First.lib <- function(libname, pkgname) {
+## .First.lib <- function(libname, pkgname) {
+.onAttach <- function(libname, pkgname) { 
   pkg <- Package(pkgname);
   assign(pkgname, pkg, pos=getPosition(pkg));
 
